@@ -118,7 +118,7 @@ Rmpfr_clear_nanflag Rmpfr_clear_overflow Rmpfr_clear_underflow Rmpfr_clears
 Rmpfr_cmp Rmpfr_cmp_IV Rmpfr_cmp_NV Rmpfr_cmp_d Rmpfr_cmp_f Rmpfr_cmp_float128 Rmpfr_cmp_ld
 Rmpfr_cmp_q Rmpfr_cmp_si Rmpfr_cmp_si_2exp Rmpfr_cmp_sj Rmpfr_cmp_ui Rmpfr_cmp_ui_2exp
 Rmpfr_cmp_uj Rmpfr_cmp_z Rmpfr_cmpabs Rmpfr_cmpabs_ui
-Rmpfr_compound_si
+Rmpfr_compound Rmpfr_compound_si
 Rmpfr_const_catalan Rmpfr_const_euler Rmpfr_const_log2 Rmpfr_const_pi
 Rmpfr_copysign
 Rmpfr_cos Rmpfr_cosh Rmpfr_cospi Rmpfr_cosu Rmpfr_cot Rmpfr_coth
@@ -192,7 +192,7 @@ prec_cast q_add_fr q_cmp_fr q_div_fr q_mul_fr q_sub_fr rndna
 
     @Math::MPFR::EXPORT_OK = (@tags, 'bytes');
 
-    our $VERSION = '4.27';
+    our $VERSION = '4.29';
     #$VERSION = eval $VERSION;
 
     Math::MPFR->DynaLoader::bootstrap($VERSION);
@@ -442,13 +442,19 @@ sub new {
 }
 
 sub Rmpfr_printf {
-    if(@_ == 3){wrap_mpfr_printf_rnd(@_)}
+    if(@_ == 3){
+      if(_itsa($_[1]) == 2) {wrap_mpfr_printf_rnd(@_)}
+      else {die "The second (of 3) arguments given to Rmpfr_printf() is not a valid rounding argument"}
+    }
     else {die "Rmpfr_printf must take 2 or 3 arguments: format string, [rounding,], and variable" if @_ != 2;
     wrap_mpfr_printf(@_)}
 }
 
 sub Rmpfr_fprintf {
-    if(@_ == 4){wrap_mpfr_fprintf_rnd(@_)}
+    if(@_ == 4){
+      if(_itsa($_[2]) == 2) {wrap_mpfr_fprintf_rnd(@_)}
+      else {die "The third (of 4) arguments given to Rmpfr_fprintf() is not a valid rounding argument"}
+    }
     else {die "Rmpfr_fprintf must take 3 or 4 arguments: filehandle, format string, [rounding,], and variable" if @_ != 3;
     wrap_mpfr_fprintf(@_)}
 }
@@ -456,8 +462,11 @@ sub Rmpfr_fprintf {
 sub Rmpfr_sprintf {
     my $len;
     if(@_ == 5){
-      $len = wrap_mpfr_sprintf_rnd(@_);
-      return $len;
+      if(_itsa($_[2]) == 2) {
+        $len = wrap_mpfr_sprintf_rnd(@_);
+        return $len;
+      }
+      else {die "The third (of 5) arguments given to Rmpfr_sprintf() is not a valid rounding argument"}
     }
     die "Rmpfr_sprintf must take 4 or 5 arguments: buffer, format string, [rounding,], variable and buffer size" if @_ != 4;
     $len = wrap_mpfr_sprintf(@_);
@@ -467,8 +476,11 @@ sub Rmpfr_sprintf {
 sub Rmpfr_snprintf {
     my $len;
     if(@_ == 6){
-      $len = wrap_mpfr_snprintf_rnd(@_);
-      return $len;
+      if(_itsa($_[3]) == 2) {
+        $len = wrap_mpfr_snprintf_rnd(@_);
+        return $len;
+      }
+      else {die "The fourth (of 6) arguments given to Rmpfr_snprintf() is not a valid rounding argument"}
     }
     die "Rmpfr_snprintf must take 5 or 6 arguments: buffer, bytes written, format string, [rounding,], variable and buffer size" if @_ != 5;
     $len = wrap_mpfr_snprintf(@_);
@@ -1435,22 +1447,6 @@ sub _decrement {
   return $ret;
 }
 
-#sub tz_test {
-#  # Detect any unwanted trailing zeroes
-#  # in values returned by nvtoa().
-#
-#  my $s = shift;
-#  my @r = split /e/i, $s;
-#
-#  if(!defined($r[1])) {
-#    return 1 if $r[0] =~ /\.0$/; # pass
-#    return 0 if $r[0] =~ /0$/;   # fail
-#  }
-#
-#  return 0 if $r[0] =~ /0$/;     # fail (for our formatting convention)
-#  return 1;                      # pass
-#}
-
 1;
 
 __END__
